==> opencv-4.5.1-1.5.5.jar: META-INF/versions/9/module-info.java <==
/* synthetic */ module org.bytedeco.opencv {
    /* transitive */ requires org.bytedeco.javacpp;
    /* transitive */ requires org.bytedeco.openblas;

    exports org.bytedeco.opencv;
    exports org.bytedeco.opencv.global;
    exports org.bytedeco.opencv.helper;
    exports org.bytedeco.opencv.presets;
    exports org.bytedeco.opencv.opencv_aruco;
    exports org.bytedeco.opencv.opencv_bgsegm;
    exports org.bytedeco.opencv.opencv_bioinspired;
    exports org.bytedeco.opencv.opencv_calib3d;
    exports org.bytedeco.opencv.opencv_core;
    exports org.bytedeco.opencv.opencv_cudaarithm;
    exports org.bytedeco.opencv.opencv_cudafilters;
    exports org.bytedeco.opencv.opencv_cudaimgproc;
    exports org.bytedeco.opencv.opencv_cudaobjdetect;
    exports org.bytedeco.opencv.opencv_cudaoptflow;
    exports org.bytedeco.opencv.opencv_dnn;
    exports org.bytedeco.opencv.opencv_face;
    exports org.bytedeco.opencv.opencv_features2d;
    exports org.bytedeco.opencv.opencv_flann;
    exports org.bytedeco.opencv.opencv_highgui;
    exports org.bytedeco.opencv.opencv_img_hash;
    exports org.bytedeco.opencv.opencv_imgproc;
    exports org.bytedeco.opencv.opencv_ml;
    exports org.bytedeco.opencv.opencv_objdetect;
    exports org.bytedeco.opencv.opencv_optflow;
    exports org.bytedeco.opencv.opencv_phase_unwrapping;
    exports org.bytedeco.opencv.opencv_photo;
    exports org.bytedeco.opencv.opencv_plot;
    exports org.bytedeco.opencv.opencv_quality;
    exports org.bytedeco.opencv.opencv_saliency;
    exports org.bytedeco.opencv.opencv_shape;
    exports org.bytedeco.opencv.opencv_stitching;
    exports org.bytedeco.opencv.opencv_structured_light;
    exports org.bytedeco.opencv.opencv_superres;
    exports org.bytedeco.opencv.opencv_text;
    exports org.bytedeco.opencv.opencv_tracking;
    exports org.bytedeco.opencv.opencv_videoio;
    exports org.bytedeco.opencv.opencv_video;
    exports org.bytedeco.opencv.opencv_videostab;
    exports org.bytedeco.opencv.opencv_xfeatures2d;
    exports org.bytedeco.opencv.opencv_ximgproc;
    exports org.bytedeco.opencv.opencv_xphoto;
    exports org.opencv.android;
    exports org.opencv.aruco;
    exports org.opencv.bgsegm;
    exports org.opencv.bioinspired;
    exports org.opencv.calib3d;
    exports org.opencv.core;
    exports org.opencv.dnn;
    exports org.opencv.face;
    exports org.opencv.features2d;
    exports org.opencv.highgui;
    exports org.opencv.imgcodecs;
    exports org.opencv.img_hash;
    exports org.opencv.imgproc;
    exports org.opencv.ml;
    exports org.opencv.objdetect;
    exports org.opencv.osgi;
    exports org.opencv.phase_unwrapping;
    exports org.opencv.photo;
    exports org.opencv.plot;
    exports org.opencv.structured_light;
    exports org.opencv.text;
    exports org.opencv.tracking;
    exports org.opencv.utils;
    exports org.opencv.video;
    exports org.opencv.videoio;
    exports org.opencv.xfeatures2d;
    exports org.opencv.ximgproc;
    exports org.opencv.xphoto;

}

==> opencv-4.5.5-1.5.7.jar: META-INF/versions/9/module-info.java <==
/* synthetic */ module org.bytedeco.opencv {
    /* transitive */ requires org.bytedeco.javacpp;
    /* transitive */ requires org.bytedeco.openblas;

    exports org.bytedeco.opencv;
    exports org.bytedeco.opencv.global;
    exports org.bytedeco.opencv.helper;
    exports org.bytedeco.opencv.presets;
    exports org.bytedeco.opencv.opencv_aruco;
    exports org.bytedeco.opencv.opencv_barcode;
    exports org.bytedeco.opencv.opencv_bgsegm;
    exports org.bytedeco.opencv.opencv_bioinspired;
    exports org.bytedeco.opencv.opencv_calib3d;
    exports org.bytedeco.opencv.opencv_core;
    exports org.bytedeco.opencv.opencv_cudaarithm;
    exports org.bytedeco.opencv.opencv_cudabgsegm;
    exports org.bytedeco.opencv.opencv_cudacodec;
    exports org.bytedeco.opencv.opencv_cudafeatures2d;
    exports org.bytedeco.opencv.opencv_cudafilters;
    exports org.bytedeco.opencv.opencv_cudaimgproc;
    exports org.bytedeco.opencv.opencv_cudaobjdetect;
    exports org.bytedeco.opencv.opencv_cudaoptflow;
    exports org.bytedeco.opencv.opencv_dnn;
    exports org.bytedeco.opencv.opencv_dnn_superres;
    exports org.bytedeco.opencv.opencv_face;
    exports org.bytedeco.opencv.opencv_features2d;
    exports org.bytedeco.opencv.opencv_flann;
    exports org.bytedeco.opencv.opencv_highgui;
    exports org.bytedeco.opencv.opencv_img_hash;
    exports org.bytedeco.opencv.opencv_imgproc;
    exports org.bytedeco.opencv.opencv_mcc;
    exports org.bytedeco.opencv.opencv_ml;
    exports org.bytedeco.opencv.opencv_objdetect;
    exports org.bytedeco.opencv.opencv_optflow;
    exports org.bytedeco.opencv.opencv_phase_unwrapping;
    exports org.bytedeco.opencv.opencv_photo;
    exports org.bytedeco.opencv.opencv_plot;
    exports org.bytedeco.opencv.opencv_quality;
    exports org.bytedeco.opencv.opencv_rapid;
    exports org.bytedeco.opencv.opencv_saliency;
    exports org.bytedeco.opencv.opencv_shape;
    exports org.bytedeco.opencv.opencv_stitching;
    exports org.bytedeco.opencv.opencv_structured_light;
    exports org.bytedeco.opencv.opencv_superres;
    exports org.bytedeco.opencv.opencv_text;
    exports org.bytedeco.opencv.opencv_tracking;
    exports org.bytedeco.opencv.opencv_videoio;
    exports org.bytedeco.opencv.opencv_video;
    exports org.bytedeco.opencv.opencv_videostab;
    exports org.bytedeco.opencv.opencv_wechat_qrcode;
    exports org.bytedeco.opencv.opencv_xfeatures2d;
    exports org.bytedeco.opencv.opencv_ximgproc;
    exports org.bytedeco.opencv.opencv_xphoto;
    exports org.opencv.android;
    exports org.opencv.aruco;
    exports org.opencv.barcode;
    exports org.opencv.bgsegm;
    exports org.opencv.bioinspired;
    exports org.opencv.calib3d;
    exports org.opencv.core;
    exports org.opencv.dnn;
    exports org.opencv.face;
    exports org.opencv.features2d;
    exports org.opencv.highgui;
    exports org.opencv.imgcodecs;
    exports org.opencv.img_hash;
    exports org.opencv.imgproc;
    exports org.opencv.ml;
    exports org.opencv.objdetect;
    exports org.opencv.osgi;
    exports org.opencv.phase_unwrapping;
    exports org.opencv.photo;
    exports org.opencv.plot;
    exports org.opencv.structured_light;
    exports org.opencv.text;
    exports org.opencv.tracking;
    exports org.opencv.utils;
    exports org.opencv.video;
    exports org.opencv.videoio;
    exports org.opencv.wechat_qrcode;
    exports org.opencv.xfeatures2d;
    exports org.opencv.ximgproc;
    exports org.opencv.xphoto;

}
